Help talk:Theme designer - Wikia Community Central
Description: Contents[show] Early, uncategorized threads I can not do that! My problem is when the My Tools...
Keywords: Community Central,wikia,Help talk:Theme designer,Sarah Manley,Mortemer2112,Merrystar,Venom00,Bob Bricks,Sam Wang,The thing,ReichMuskrat15,2Actimv,1999bug

# Wikia

Skip to Content Skip to Wiki Navigation Skip to Site Navigation

#

Watchlist Random page Recent changes

# Talk:Theme designer

86,821pages on
this wiki

## Back to page

Got a question about this topic? Head on over to the Forum!
You can use this space to suggest improvements to the help page. | You can submit bug reports about this topic to Wikia Support.

## Early, uncategorized threads Edit

  I can not do that! My problem is when the My Tools, there is nothing "Special: Themedesigner. For the love of God: HEEELLP MEEE!!!--User:LigadajustiçaSmallville 22:01, October 11, 2010 (UTC)

    Are you looking on a wiki that you are an admin on? You need to be an admin to use this tool. If you want to test it out, you can on the theme designer wiki. If not, please give me more details. --Sarah (Help Forum) (blog) 02:40, October 12, 2010 (UTC)

The theme designer is a new tool for the "new wiki look". You can change to it by going to your preferences and chosing the new theme instead of monaco. I have figured that much out. I'm having a major problem with this new tool. The three top buttons: theme, custom, and wordmark are all unresponsive to a click. Also, the wiki preview picture is only a tiny box with scrollbars not a full-page view that would be expected. Is this an error in the system that is being fixed? Or am I doing it wrong? Mortemer2112 01:10, October 12, 2010 (UTC)

  What browser are you on? Can you send more details and a screenshot to Special:contact and we will work to get this fixed right away. Best, --Sarah (Help Forum) (blog) 02:40, October 12, 2010 (UTC)

I'm using Internet explorer, I've sent a screenshot in I hope it helps. Mortemer2112 19:31, October 14, 2010 (UTC)

  Hi, thanks for helping me! I'm on Google Chrome. Yes I am admin of a wiki. I'm trying to change the background and the designer of the Wiki. Since then I am very confused. We see the "My Tools" on the page: Wikia.com, right? I see, but had no "History". I tried to edit the My Tools, but found no Special: Themedesigner. We see the "My Tools" on the page: http://www.wikia.com/Wikia, right? I see, but had no "History". I tried to edit the My Tools, but found no Special: Themedesigner. Understood, I wish you, Sarah, explain to me how blessed I would find the "Special: Themedesigner".--LigadajustiçaSmallville 14:35, October 12, 2010 (UTC)

    What wiki are you having a problem on?--Sarah (Help Forum) (blog) 17:09, October 12, 2010 (UTC)

  The Wiki is in Portuguese of Brazil. The link is this: T.I.M.E Wiki! Thank you Sarah! --LigadajustiçaSmallville 21:49, October 12, 2010 (UTC)

    Hi, I just checked your account on chrome, and it appeared that you did not have the new look selected in your preferences. Once I chose this option, it gave your account access to theme designer. Let me know if this continues not to work. Best, --Sarah (Help Forum) (blog) 23:20, October 12, 2010 (UTC)

  Pardon my delay in responding, was busy. Hi, I prefer the old view of the Wiki. But if the problem is this, I change. But I have no access to Special: Themedesigner. That's my objective was to create a new theme for my Wiki. A blue tone. I wanted to access what is appearing in the picture.--LigadajustiçaSmallville 23:23, October 13, 2010 (UTC)

Hello LigadajustiçaSmallville, You still did not change your settings, so I did it for you. You can now access the theme designer here. Best, --Sarah (Help Forum) (blog) 16:26, October 14, 2010 (UTC)

  Hi Sarah, thanks for helping me in the Theme designer! I was the editing and arrived at the "wordmark" and not know the size and scale of the graphic image but the image is ready, lack fit the size available to post on the graphic.--LigadajustiçaSmallville 22:42, October 20, 2010 (UTC)

    The wordmark must be an png file and 250 x 65 px. You can use a tool like http://pixlr.com/editor/ to adjust it. Cheers, --Sarah (Help Forum) (blog) 23:56, October 20, 2010 (UTC)

  Oh Sarah. I turned the 250 px image, but could not put in the wordmark. You can change the picture for me?
  And how do I put for unregistered users when they come to my Wiki page, see the new look of Wikia.--LigadajustiçaSmallville 16:15, October 26, 2010 (UTC)

    Hello, I resized and added the wordmark for you, so enjoy! Now all users will see the new look. Happy editing, --Sarah (Help Forum) (blog) 18:39, October 26, 2010 (UTC)

## Help Edit

Hi, I'm an administrator at Logopedia (Logos Wikia), and I'm wondering about how to change this new wiki look back to the regular Monaco Sapphire skin. I want this for every user, not just for me. Please tell me how to change it back. Thanks! --Alxeedo TALK 20:04, October 18, 2010 (UTC)

  Hi Alxeedo, you can change your personal preferences to show Monaco until Nov 3rd for just you. It is not possible to change it back for other users. On Nov 3rd, Monaco will be removed as an option. The "Oasis" theme in the theme designer is similar to sapphire, so you may want to experiment with using that. Best, --Sarah (Help Forum) (blog) 23:15, October 18, 2010 (UTC)

## Dimensions Edit

What dimensions would work best for the custom background graphic (not the wordmark)? --れび (talk to Lavi!) 01:21, October 28, 2010 (UTC)

  Hi. It depends a bit on what you want for a background. If it is a pattern that can be tiled, then you can use any size image that you like. If you would like a single image, the vertical height would depend on how far down the page you want it to extend. In terms of width, a single image needs to be wider than 960px, which is the width of the content and sidebar area, or it won't be seen around them. How much wider depends again on what you want to put there (and what you can fit within the filesize limit of 100 kilobytes). As an example, something in the realm of 1400x600 would be reasonable -- it would extend at least halfway down most users' screens; just choose a background color that will look good below it and to the sides on bigger screens. -- Wendy (talk) 01:01, October 29, 2010 (UTC)

## Invisible Wordmark Edit

Hi I am having a problem with my wordmark. I have repeatedly tried using a 250x65 .PNG image and this is what happens. It appears fine in the theme designer so I click save. But then it doesn't show up after I save. I re-open theme designer and the image preview of it (besides the box that says: dont use a graphic) is only a small box with a red X, hinting that the image file is invalid even though it shows up fine when first uploaded.

  I'm having a similar problem. I have uploaded a background image and a wordmark and it is fine in the designer but when saved doesn't show. I even deleted the old File:Wiki-wordmark.png but it still displays, what is with that? It's a bit worrying that the new skin is supposed to go live in the next couple of days but I can't get a theme working. --Squilibob 22:54, October 29, 2010 (UTC) (sealonline.wikia.com)
  Hi, I see a wordmark on sealonline.wikia.com, is that not the right one? Or has it showed up now? --Sarah (Help Forum) (blog) 18:47, November 1, 2010 (UTC)
    The bug seems to have been fixed, thanks. --Squilibob 23:41, November 1, 2010 (UTC)

## You can not do that! Edit

It is now that we can not choose and change the style sheet for Monaco Custom? There must be freedom of choice! --DCamer 21:16, October 30, 2010 (UTC)

I tried to put any graphic background and wordmark and nothing. NOTHING!!! What's up? Danielvalle2222 04:20, February 13, 2012 (UTC)

  Please send in a link to the wiki, your browser info and any screenshots via Special:Contact. Also, in the future, best to start a new section at the bottom when posting these types of questions there. Sarah (help forum | blog) 18:53, February 13, 2012 (UTC)

## Advanced CSS Edit

Hello, the main wiki I edit on, the Calvin and Hobbes Wiki, has advanced CSS coding in the Common.css file for use on the main page and other pages. I was wondering if I could somehow transfer that code from the Common.css file to another file so that it will also work in the new wikia theme. Thank you, Brovie talk 06:31, November 6, 2010 (UTC)

  Yes you can add it to Wikia.css --Sarah (Help Forum) (blog) 00:48, November 9, 2010 (UTC)
    Thank you! --Brovie talk 04:53, November 9, 2010 (UTC)

## Multiple Themes Edit

Maybe this is a stupid question, but, as a new Administrator on the Mortal Kombat Wiki, I'm curious if there's a way to make multiple themes. That is to say, allow registered users to choose which theme they'd like to see the wikia displayed as. Is there a way? —CavalierTunestalk 17:40, December 24, 2010 (UTC)

  Users can use their personal preference to choose between the admin theme or monobook, but there is not a way to set a different theme for different types of users. --Sarah (Help Forum) (blog) 18:59, December 27, 2010 (UTC)
    Thank you, but I think I asked my question incorrectly. I was trying to ask if there was a way to create multiple admin themes that users can choose from under their personal preferences. For instance, if a random user went to his or her personal preferences, could they choose between "Monobook," "Admin Theme 1," "Admin Theme 2," etc. Or can there be only one admin theme? I'm not asking if I can create different themes for different types of users, just if I can create multiple themes for users to choose from under their personal preferences. I hope that was less ambiguous. —CavalierTunestalk 17:56, December 31, 2010 (UTC)

## Tables Edit

When I changed the customizable page color (for the background), it messed up the wikitables, making the borders a different color and making the backgroungs match. While the matching/transparent background is fine, is there a way to make the borders stay the default black? Neocarleen • Talk 09:12, January 17, 2011 (UTC)

## Background image does not load properly Edit

Hello, I'm experiencing some problems with my wiki's background image. For some reason, whenever I update the background image, the old one still presents as the current image. I have tried to switch back and forth between old and new images but nothing changed. The small preview images in the file's history indicated that there was nothing wrong with the upload process or the file (at least that is what I think), so I guess there must be some problems with displaying system. Is there anyway to overcome this? Venom00 05:52, February 16, 2011 (UTC)

- Hi, I am not a offical STAFF but I can help you -βᵒᵇ βʳᶦᶜᵏˢ™ Ʈᵃᶫᵏ · βᶫᵒᵍ

- - You need to use MediaWiki:Wikia.css, put this coding down but switch BACKGROUND with the background image link

{

     body.mediawiki  {
     background:#0F5835 url(BACKGROUND) fixed center top repeat !important;
     background-repeat-x: repeat !important;
     background-repeat-y: repeat !important;
     background-color: #0F5835!important

{

## Recent changes to Theme Designer Edit

Do the recent changes to the Theme Designer related to the `WikiaPage` and `WikiaPageBackground` elements require any changes to the instructions/explanations provided here? I am specifically thinking of notes on how to use the new transparency bar under the page background settings. Thanks! — Spike Toronto 05:40, July 30, 2011 (UTC)

  I have a problem with the transparency bar. I tried to adjust it to make the foreground transparent but after I clicked "I'm done", nothing has changed and when I went back to the Theme designer, it bar was where it was before I changed it. EpsilonIndi 16:20, July 30, 2011 (UTC)

    Epsilon: You should post your question at the Community Central forum. You should do this for several reasons:
    1. These Help Wiki talk pages have very little traffic, so no one with an answer is likely to come by here for some time (weeks or months even)
    2. These Help Wiki talk pages are for discussing changes/improvements to the Help Wiki articles.
    3. The Community Central forums are the central location for solving problems
    4. The Community Central forums have very high traffic of people who have the expertise to answer your question within hours
    Thanks! — Spike Toronto 20:08, July 30, 2011 (UTC)

## How to change Wordmark? Edit

Hi, I am the founder of Isle of Tune Wiki and the wiki is already created. How can I change the Wordmark?
Sam Wang 05:03, October 11, 2011 (UTC)

  You can use the wordmark section of the theme designer. If you need further help, try and post in the founder & admin forum. Cheers, --Sarah (help forum | blog) 16:08, October 21, 2011 (UTC)

I have a question: I have a wiki name logo for Charlie Bone Wiki, [1] and there are no local admins on that wiki. So what can I do? --Lao 21:11, October 20, 2011 (UTC)

  You can apply to adopt it - which will give you admin rights. You can apply here. Best, --Sarah (help forum | blog) 16:08, October 21, 2011 (UTC)

## Help Edit

On my Wiki, eveytime time I try to upload a favicon or wordmark it keeps saying "File extension does not match MIME type," and it's becoming very frustrating. Can someone please help?

--A hero boy named Finn

  Are you sure you are using the right file types? For the workmark it has to be a png file and for the favicon it has to be ico. If not, they won't work. Sarah (help forum | blog) 19:18, December 24, 2011 (UTC)

## Help :c Edit

How I can put images on the header?

Archivo:Th_mlp_rainbow_dash_sprite_2_by_blaze33193-d3lmwke.png Rainbow Dash!~ 03:41, January 1, 2012 (UTC)

## Theme Choosing. Edit

Recently on DragonVale Wiki was a theme change, which, personally, I hate. Now, I was looking into this regarless, but I would love to know: is there a tool to let people choose their own themes from some set ones? I think the desired parchment effect is just no. With the love this theme is getting I don't think it will be changed, but I would love to change to another theme, hate to stick with this one, and giving other users and anons the choice would make everyone happy. To clarify, a tool to let everyone decide from set themes for their personal browsing. The new one I find literally unbearable. I can't look at it without saying, "ew!". Really, I am just considering leaving since I'm not very active anyway and I hate the design, downing my motivation to visit. If this tool does not exist, please, create it. It would be a great item to add everywhere, because it would cut down on any possible skin arguments and let everybody set the look they want. Also, is it in production at all, if not already available? ~Nibe - DragonVale Bureaucrat - Talk | Blog 06:34, February 3, 2012 (UTC)

  Hello, There isn't an easy way to create your own personal view of the wiki. You can modify your personal css and js file to adjust your look, but this can be a bit complicated. I would recommend posting on our support forum to see if other users are able to share with you the modifications they have made. Best of luck, Sarah (help forum | blog) 17:17, February 3, 2012 (UTC)

## Upload wont work in theme desginer Edit

Hi, im currently working on two wikis as an admin. I'm having a lot of trouble with uploading my own images for backgorunds, wordmarks etc.

All my grapghics fit the size and file type criteria, but when i click upload, nothing happens.

The first wiki, baldursgategame.wiki.com and the second is jackass.wiki.com

These are the two graphic wordmarks i'm trying to upload....

I'm also having the same problem with my jackass facIcon.

Thanks in advance... Thomaslove92 22:39, March 1, 2012 (UTC)

- EDIT: I've fixed this..i was using google chrome. Works fine in Firefox. This maybe should be addressed however. Thomaslove92 01:53, March 2, 2012 (UTC)

Thanks for letting us know and happy to hear its fixed. What wikis exactly was it happening on? Sarah (help forum | blog) 17:02, March 2, 2012 (UTC)

- It was on baldursgategame.wiki.com and jackass.wiki.com - it appears just to be an issue with google chrome. Thomaslove92 22:18, March 3, 2012 (UTC)

## Background not uploading? Edit

I believe I have experienced this problem before, but I can't get around it this time. While helping a friend at w:c:thelegospace with the theme, I am unable to make the background image show. Instead of this, it keeps the old background. I tried deleting the wiki-background file and whatnot, but it still doesn't show the new one. Any .css I could add to make the background show? If so, I'd appreciate it. Thanks, - Bug

  This is happening with the wordmark on my wiki. The thing Talk 22:53, April 1, 2012 (UTC)

- Hi, I am not a offical STAFF but I can help you -βᵒᵇ βʳᶦᶜᵏˢ™ Ʈᵃᶫᵏ · βᶫᵒᵍ

- - You need to use MediaWiki:Wikia.css, put this coding down but switch BACKGROUND with the background image link

{

     body.mediawiki  {
     background:#0F5835 url(BACKGROUND) fixed center top repeat !important;
     background-repeat-x: repeat !important;
     background-repeat-y: repeat !important;
     background-color: #0F5835!important

{

## So, Wait...Edit

If I change the theme, does it only change it for MY account, or does everyone else see it too? Like, If I make everything purple, will everyone else see purple, or only me?

{{subst:User:JessiPhan/Sig}} 02:14, April 12, 2012 (UTC) JessiPhan

- Yes every one else will beable to see the purple. -βᵒᵇ βʳᶦᶜᵏˢ™ Ʈᵃᶫᵏ · βᶫᵒᵍ

## Help Saving Theme Edit

I'm an admin on 28 Days Later Wiki, and I'm trying to change the background image, but whenever I save the change, it just keeps the original background image! Could someone please help me with this. TroopDude 12:40, May 12, 2012 (UTC)

- Hi, I am not a offical STAFF but I can help you -βᵒᵇ βʳᶦᶜᵏˢ™ Ʈᵃᶫᵏ · βᶫᵒᵍ

- - You need to use MediaWiki:Wikia.css, put this coding down but switch BACKGROUND with the background image link

{

     body.mediawiki  {
     background:#0F5835 url(BACKGROUND) fixed center top repeat !important;
     background-repeat-x: repeat !important;
     background-repeat-y: repeat !important;
     background-color: #0F5835!important

{

## Why does it keep cutting my background image? Edit

I have my picture, and it's at 1600px wide. It's 1100 tall and within the file size limits. I want it to be fixed.

When I upload the image, it cuts off the outer edges. Why is this?
What it SHOULD look like
What it ACTUALLY looks like

It's like Wikia "zooms in" on it. I just want the stuff on the edges to be showing, but it simply does work. What is causing this, and how can I fix it?

Thanks.

Bienvenue dans notre univers! Retrouve-nous au coeur de ta memoire. 22:29, June 19, 2012 (UTC)

- Hi, I am not a offical STAFF but I can help you, you can try using MediaWiki.css, you need to post this coding down in the wiki

{

      body.mediawiki  {
      background:#0F5835 url(http://images3.wikia.nocookie.net/__cb20120619222302/tsclg/images/5/50/Wiki-background) fixed center top repeat !important;
      background-repeat-x: repeat !important;
      background-repeat-y: repeat !important;
      background-color: #0F5835!important;

{

-βᵒᵇ βʳᶦᶜᵏˢ™ Ʈᵃᶫᵏ · βᶫᵒᵍ

## Favicon Edit

I've uploaded my favicon about 4 times. It's 16 x 16, it's a .ico file, it uploads fine, but when I save my changes, it doesn't change from the default. I've tried adding ?action=purge, too. No difference. --GwenhwyfarRaven (talk) 07:17, September 23, 2012 (UTC)

## Multi-Theme Edit

Is there a possible way to set up multiple themes for a wiki? Not where a user can select their own theme, but where a few pages have their own unique theme. Submachiner (talk) 21:27, October 2, 2012 (UTC)\

## Editor problem Edit

Hi. I have a big problem on my wiki, Warriorz Fanfiction Wiki.

I've gone to the theme designer page, but when I click one of the tabs (Theme, Customize and Wordmark) on the top left, the board on the right where all the editing options for the wiki's background and whatnot don't show up. The board stays blank.

PLEASE help me!!!! Kittycat79Melodyfrost: Mate of Hawkfrost 09:16, December 20, 2012 (UTC)

  Hey there, Can you send in all the details (link to wiki, your browswer info and a screenshot) to Special:Contact? This wil help us in figuring out the issue. Thanks, Sarah (help forum | blog) 17:29, December 20, 2012 (UTC)

  K, I did that. Thanks. Kittycat79Melodyfrost: Mate of Hawkfrost 02:27, December 21, 2012 (UTC)

## Background problem Edit

So the basic problem is that the background only shows up on some of my pages. It mostly shows up on all, I think, but not my user page and not my main page. Now this might just be a bug, but it's highly annoying. The wiki in discussion is http://tiffanyalvord.wikia.com ~Xo MinniHowl (talk) 18:37, January 8, 2013 (UTC)

  I see it on all pages. What shows when you don't see it? What browser and version are you on? Sarah (help forum | blog) 18:55, January 8, 2013 (UTC)

everytime i try to upload a new background picture it wont let me. i have the right file type and it's not over 150kb and it shows i have it selected but it doesn't do anything when i click upload. pleez help. ReichMuskrat15 (talk) 22:22, February 23, 2013 (UTC)

  Responded on your message wall. Sarah (help forum | blog) 18:54, February 25, 2013 (UTC)

## Specific wordmark for specific pages Edit

Why the admin central of this wiki had a different wordmark? Can you make a specific wordmark dor specific pages?DarkTimes2013 (talk) 05:44, July 3, 2013 (UTC)

## Background issues Edit

I am having trouble with the background on my wiki . The background is stuck on the previous imageupoaded, and won't change to the new one. Despite this, when I open up the theme designer it claims I am using the new image for my background.

Nototter (talk) 00:58, September 8, 2013 (UTC)

  I see it as tiled and appears to be the latest version - has it updated for you now? Sarah (help forum | blog) 16:35, September 9, 2013 (UTC)

## What if..Edit

What if the founder of the wikia is no longer contributing and there are no admins? Some of us really want to change the BG and the title of It Girl Wikia , but we can't. The "administrator" role can be gived to another contributor(s)?

MaryJones (talk) 16:13, October 15, 2013 (UTC)MaryJones

You can fill in the adoption form on this wiki to get the rigths, so you can do these things. 2Actimv talk 17:39, October 16, 2013 (UTC)

## Dragon Ball Fanon problems Edit

Some problems:

1. The original theme just disappeared on us about halfway through the day of 11/7/2013.
2. Attempts to revert the theme to an earlier version did not bring up any theme. Only a dark purple background remained if any attempt was made.
3. After uploading a new theme (which was not the correct size), I am unable to upload any more. If I upload a new custom-made theme, it shows the original, incorrectly-sized one. Even if I upload a different picture, it will still show that first image. So I'm just completely unable to use this tool. Is there any possible way to get around this glitch-ridden system and get a theme for the wiki at all? -KidVegeta (talk)

## Ice Age Wiki Edit

I've been the current admin of the Ice Age Wiki for some time. One thing I've wanted changed on there is the current background. I have found an image from the Ice Age films online that I cleaned up a little so as to make it blank and devoid of characters and promptly uploaded it. However, once I attempted to make that image in particular the Wiki's background, it got cornered to the upper left side of the screen; that is, it technically is the background, but it has shrunken horribly and doesn't cover even a slight bit of the area I intended. I've tried to make the image smaller, I've tried multiple uploads of the same thing over again, but none of it works. This said, might someone be able to lend a hand in correcting the thing once and for all?--Macrauchenia (talk) 02:58, November 15, 2013 (UTC)

Retrieved from "http://community.wikia.com/wiki/Help_talk:Theme_designer?oldid=1142554"

Lifestyle Entertainment Video Games